import React, { useCallback, useEffect, useMemo, useRef, useState, } from "react";
import { filesize } from "filesize";
import useSize from "./useSize";
import * as Styles from "./style";
import Tooltip from "../../Tooltip";
import SvgFromUrl from "../../SvgFromUrl";
function VideoAttachment(props) {
    var _a, _b;
    const [hasPlayedOnceBefore, setHasPlayedOnceBefore] = useState(false);
    const [paused, setPaused] = useState(true);
    const [showPlayOrPauseAnimation, setShowPlayOrPauseAnimation] = useState(false);
    const [durationPlayed, setDurationPlayed] = useState(0);
    const [isFullscreen, setIsFullscreen] = useState(false);
    const [isSeeking, setIsSeeking] = useState(false);
    const videoRef = useRef(null);
    const attachmentRef = useRef(null);
    const durationPlayedHumanized = useMemo(() => {
        var _a, _b, _c, _d;
        const minutesPassed = Math.floor(((_a = videoRef.current) === null || _a === void 0 ? void 0 : _a.currentTime) / 60);
        const secondsPassedRaw = Math.floor(((_b = videoRef.current) === null || _b === void 0 ? void 0 : _b.currentTime) % 60);
        const secondsPassed = secondsPassedRaw < 10 ? `0${secondsPassedRaw}` : secondsPassedRaw;
        const minutesTotal = Math.floor(((_c = videoRef.current) === null || _c === void 0 ? void 0 : _c.duration) / 60);
        const secondsTotalRaw = Math.floor(((_d = videoRef.current) === null || _d === void 0 ? void 0 : _d.duration) % 60);
        const secondsTotal = secondsTotalRaw < 10 ? `0${secondsTotalRaw}` : secondsTotalRaw;
        return `${minutesPassed}:${secondsPassed}/${minutesTotal}:${secondsTotal}`;
    }, [durationPlayed, videoRef.current]);
    function playVideo() {
        const video = videoRef.current;
        if (video === null)
            return;
        if (video.paused)
            video.play();
        else
            video.pause();
    }
    const updatePauseState = useCallback((pauseState) => {
        setPaused(pauseState);
        setShowPlayOrPauseAnimation(true);
        setTimeout(() => setShowPlayOrPauseAnimation(false), Styles.PlayOrPauseAnimationDuration);
    }, []);
    const { width: extractedWidth, height: extractedHeight } = "video" in props.attachmentOrEmbed
        ? props.attachmentOrEmbed.video
        : props.attachmentOrEmbed;
    const { width, height } = useSize(extractedWidth, extractedHeight, isFullscreen);
    function fullScreenChange() {
        setIsFullscreen(document.fullscreenElement !== null);
    }
    function seekVideo(e, overrideSeeking) {
        var _a;
        if (videoRef.current === null || (!isSeeking && !overrideSeeking))
            return;
        const rect = e.target.getBoundingClientRect();
        const x = e.clientX - rect.left;
        const duration = (_a = videoRef.current) === null || _a === void 0 ? void 0 : _a.duration;
        if (duration === undefined)
            return;
        videoRef.current.currentTime = (x / rect.width) * duration;
    }
    useEffect(() => {
        document.addEventListener("fullscreenchange", fullScreenChange);
        return () => {
            document.removeEventListener("fullscreenchange", fullScreenChange);
        };
    }, []);
    return (React.createElement(Styles.VideoAttachmentContainer, { style: { width, height }, ref: attachmentRef },
        React.createElement(Styles.VideoAttachment, { preload: "metadata", src: props.attachmentOrEmbed.url, height: height, width: width, ref: videoRef, onPause: () => updatePauseState(true), onPlay: () => {
                updatePauseState(false);
                setHasPlayedOnceBefore(true);
            }, onTimeUpdate: ({ timeStamp }) => setDurationPlayed(timeStamp) }),
        React.createElement(Styles.VideoAttachmentOverlay, { "data-paused": paused, "data-played-once": hasPlayedOnceBefore },
            (showPlayOrPauseAnimation || !hasPlayedOnceBefore) && (React.createElement(Styles.PlayOrPauseButtonAnimation, { "data-paused": paused, "data-has-played-before": hasPlayedOnceBefore },
                React.createElement(SvgFromUrl, { width: 12, height: 12, svg: paused ? "IconPlay" : "IconPause" }))),
            "filename" in props.attachmentOrEmbed && (React.createElement(Styles.VideoMetadata, null,
                React.createElement(Styles.VideoMetadataTitle, null, props.attachmentOrEmbed.filename),
                React.createElement(Styles.VideoMetadataFilesize, null, filesize(props.attachmentOrEmbed.size, { base: 2 })))),
            React.createElement(Styles.VideoAttachmentOverlayControl, { onClick: playVideo }),
            React.createElement(Styles.VideoControls, null,
                React.createElement(Styles.VideoControlButton, { width: 14, height: 14, svg: paused ? "IconPlay" : "IconPause", onClick: playVideo }),
                width > 200 && (React.createElement(Styles.VideoControlsTime, null, durationPlayedHumanized)),
                React.createElement(Styles.ProgressBar, { onMouseMove: seekVideo, onClick: (e) => seekVideo(e, true), onMouseDown: () => setIsSeeking(true), onMouseUp: () => setIsSeeking(false) },
                    React.createElement(Styles.ProgressBarFill, { style: {
                            width: (((_a = videoRef.current) === null || _a === void 0 ? void 0 : _a.currentTime) / ((_b = videoRef.current) === null || _b === void 0 ? void 0 : _b.duration)) *
                                100 +
                                "%",
                        } })),
                React.createElement(Tooltip, { placement: "top", overlay: "Full Screen" },
                    React.createElement(Styles.VideoControlButton, { width: 14, height: 14, svg: "IconFullscreen", onClick: () => {
                            var _a;
                            if (document.fullscreenElement === null)
                                (_a = attachmentRef.current) === null || _a === void 0 ? void 0 : _a.requestFullscreen();
                            else
                                void document.exitFullscreen();
                        } }))))));
}
export default VideoAttachment;
//# sourceMappingURL=VideoAttachment.js.map