import GifVEmbed from "./GifVEmbed";
import ImageEmbed from "./ImageEmbed";
import VideoAttachment from "../Attachment/VideoAttachment";
import * as Styles from "./style";
import numberToRgb from "../../utils/numberToRgb";
import moment from "moment";
import { LinkMarkdown, parseEmbedTitle } from "../../markdown/render";
import useSize from "./useSize";
import EmbedVideo from "./EmbedVideo";
import React, { useMemo } from "react";
import { EmbedType } from "discord-api-types/v10";
function Embed({ embed, images }) {
    var _a, _b;
    if (embed.type === EmbedType.GIFV)
        return React.createElement(GifVEmbed, { embed: embed });
    if (embed.type === EmbedType.Image)
        return React.createElement(ImageEmbed, { embed: embed });
    if (embed.type === EmbedType.Video && !embed.thumbnail)
        return React.createElement(VideoAttachment, { attachmentOrEmbed: embed });
    const embedColor = embed.color !== 0 && embed.color !== undefined
        ? numberToRgb(embed.color)
        : undefined;
    const { width: widthImage, height: heightImage } = useSize(embed.type, embed.image, "EmbedImage", (images === null || images === void 0 ? void 0 : images.length) > 0);
    const { width: widthThumbnail, height: heightThumbnail, isLarge: isThumbnailLarge, } = useSize(embed.type, embed.thumbnail, "EmbedThumbnail", undefined);
    const isEmbedThin = useMemo(() => widthImage !== null ||
        (embed.type === EmbedType.Video && embed.thumbnail !== null), [widthImage, embed.type, embed.thumbnail]);
    return (React.createElement(Styles.Embed, { style: { borderLeftColor: embedColor }, thin: isEmbedThin },
        React.createElement(Styles.ContentAndThumbnail, { hasLargeThumbnail: isThumbnailLarge },
            React.createElement(Styles.Content, null,
                embed.provider && (React.createElement(Styles.Provider, null, embed.provider.name)),
                embed.author && (React.createElement(Styles.Author, null,
                    embed.author.proxy_icon_url && (React.createElement(Styles.AuthorIcon, { src: embed.author.proxy_icon_url })),
                    React.createElement(Styles.AuthorName, null, embed.author.url ? (React.createElement("a", { href: embed.author.url, target: "_blank", rel: "noreferrer noopener" }, embed.author.name)) : (embed.author.name)))),
                embed.title &&
                    (embed.url !== undefined ? (React.createElement(Styles.Title, { as: "a", link: true, href: embed.url, target: "_blank" }, parseEmbedTitle(embed.title))) : (React.createElement(Styles.Title, null, parseEmbedTitle(embed.title)))),
                embed.type === EmbedType.Video ? (React.createElement(EmbedVideo, { url: embed.video.url, proxyUrl: embed.video.proxy_url, width: embed.video.width, height: embed.video.height, thumbnail: embed.thumbnail.proxy_url })) : (embed.description && (React.createElement(Styles.Description, null,
                    React.createElement(LinkMarkdown, null, embed.description)))),
                embed.fields && embed.fields.length > 0 && (React.createElement(Styles.Fields, null, embed.fields.map((field) => (React.createElement(Styles.Field, { key: field.name + field.value, inline: field.inline },
                    React.createElement(Styles.FieldName, null, parseEmbedTitle(field.name)),
                    React.createElement(Styles.FieldValue, null,
                        React.createElement(LinkMarkdown, null, field.value)))))))),
            embed.thumbnail && embed.type !== EmbedType.Video && (React.createElement(Styles.Image, { src: embed.thumbnail.proxy_url, 
                // originalUrl={embed.thumbnail.url}
                width: widthThumbnail, height: heightThumbnail }))),
        (images === undefined || (images === null || images === void 0 ? void 0 : images.length) === 0) && embed.image && (React.createElement(Styles.Image, { src: embed.image.proxy_url, 
            // originalUrl={embed.image.url}
            width: widthImage, height: heightImage })),
        (images === null || images === void 0 ? void 0 : images.length) > 0 && (React.createElement(Styles.Images, { nImages: images.length }, images.map((image) => (React.createElement(Styles.ImageGridImageContainer, { key: image.url },
            React.createElement(Styles.Image, { src: image.proxy_url, 
                // originalUrl={image.url}
                withMargin: true })))))),
        (embed.footer || embed.timestamp) && (React.createElement(Styles.Footer, null,
            ((_a = embed.footer) === null || _a === void 0 ? void 0 : _a.proxy_icon_url) && (React.createElement(Styles.FooterIcon, { src: embed.footer.proxy_icon_url })), (_b = embed.footer) === null || _b === void 0 ? void 0 :
            _b.text,
            embed.timestamp && (React.createElement(React.Fragment, null,
                " • ",
                moment(embed.timestamp).calendar()))))));
}
export default Embed;
//# sourceMappingURL=index.js.map