import React, { Children, memo, useMemo } from "react";
import Moment from "moment/moment";
import Message from "../Message";
import * as Styles from "./style";
import { MessageFlags } from "discord-api-types/v10";
import Tooltip from "../Tooltip";
import SvgFromUrl from "../SvgFromUrl";
import Markdown, { LinkMarkdown } from "../markdown/render";
import Attachment from "./Attachment";
import Sticker from "./Sticker";
import Embed from "./Embed";
import Reactions from "../Message/Reactions";
import ThreadButton from "./Thread/ThreadButton";
import Components from "../Message/Components";
import getDisplayName from "../utils/getDisplayName";
const Edited = memo((props) => {
    return (React.createElement(Tooltip, { overlay: Moment(props.editedAt).format("LLLL"), placement: "top", mouseEnterDelay: 1 },
        React.createElement(Styles.Edited, null, "(edited)")));
});
function ReplyIcon({ message }) {
    var _a;
    if (message.interaction)
        return React.createElement(Styles.ReplyIcon, { width: 20, height: 20, svg: "IconCommand" });
    if (((_a = message.sticker_items) === null || _a === void 0 ? void 0 : _a.length) > 0)
        return React.createElement(Styles.ReplyIcon, { width: 20, height: 20, svg: "IconSticker" });
    if (message.attachments.length > 0 || message.embeds.length > 0)
        return React.createElement(Styles.ReplyIcon, { width: 20, height: 20, svg: "IconAttachment" });
    return null;
}
function MessageAccessories({ children, active }) {
    if (!active || !children || Children.count(children) === 0)
        return React.createElement(React.Fragment, null);
    return React.createElement(Styles.MessageAccessories, null, children);
}
function ContentCore(props) {
    if (!props.showTooltip)
        return React.createElement(React.Fragment, null, props.children);
    return (React.createElement(Tooltip, { overlay: React.createElement(Styles.ContentMessageTooltip, null,
            React.createElement(Message, { message: props.referencedMessage, isFirstMessage: true })), placement: "top", trigger: ["click"] }, props.children));
}
function Content(props) {
    var _a, _b, _c, _d, _e, _f, _g;
    const dominantAccessoryText = useMemo(() => {
        var _a;
        if (!props.isReplyContent)
            return null;
        if (props.message.interaction)
            return "Click to see command";
        if (((_a = props.message.sticker_items) === null || _a === void 0 ? void 0 : _a.length) > 0)
            return "Click to see sticker";
        if (props.message.attachments.length > 0 || props.message.embeds.length > 0)
            return "Click to see attachment";
        return null;
    }, [props.message.attachments, props.message.stickers, props.isReplyContent]);
    const embedImages = useMemo(() => {
        if (!props.message.embeds ||
            props.message.embeds.length <= 1 ||
            props.message.embeds[0].url === undefined)
            return [];
        if (!props.message.embeds.every((e) => e.url !== undefined && props.message.embeds[0].url === e.url))
            return [];
        const images = props.message.embeds
            .reduce((acc, embed) => [...acc, embed.image], [])
            .filter((i) => i !== null && i !== undefined);
        if (images.length === 0)
            return [];
        return images;
    }, [props.message.embeds]);
    if (props.message.flags & MessageFlags.Loading) {
        const fifteenMinutes = 15 * 60 * 1000;
        if (Date.now() - new Date(props.message.timestamp).getTime() >
            fifteenMinutes)
            return (React.createElement(Styles.FailedInteraction, null,
                React.createElement(SvgFromUrl, { width: 16, height: 16, svg: "IconDanger" }),
                React.createElement("span", null, "The application did not respond")));
        return (React.createElement(Styles.DeferredContent, null,
            React.createElement(Styles.TypingIndicator, { width: 25.5, height: 7, style: { marginRight: 5 } },
                React.createElement("g", null,
                    React.createElement(Styles.TypingIndicatorCircle1, { cx: "3.5", cy: "3.5", r: "3.5", fill: "currentColor" }),
                    React.createElement(Styles.TypingIndicatorCircle2, { cx: "12.25", cy: "3.5", r: "3.5", fill: "currentColor" }),
                    React.createElement(Styles.TypingIndicatorCircle3, { cx: "21", cy: "3.5", r: "3.5", fill: "currentColor" }))),
            getDisplayName(props.message.author),
            " is thinking..."));
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(Styles.Base, { isReplyContent: props.isReplyContent },
            React.createElement(ContentCore, { referencedMessage: props.message, showTooltip: props.isReplyContent },
                React.createElement(Styles.ContentContainer, { isReplyContent: props.isReplyContent }, props.message.content.length > 0 ? (React.createElement(React.Fragment, null,
                    props.message.webhook_id !== undefined ? (React.createElement(LinkMarkdown, { mentions: props.message.mentions }, props.message.content)) : (React.createElement(Markdown, { mentions: props.message.mentions }, props.message.content)),
                    props.message.edited_timestamp && (React.createElement(Edited, { editedAt: props.message.edited_timestamp })))) : (React.createElement(Styles.ReplyAccessoryText, null, dominantAccessoryText)))),
            props.isReplyContent && React.createElement(ReplyIcon, { message: props.message })),
        !props.isReplyContent && (React.createElement(MessageAccessories, { active: ((_a = props.message.reactions) === null || _a === void 0 ? void 0 : _a.length) > 0 ||
                props.message.attachments.length > 0 ||
                ((_b = props.message.sticker_items) === null || _b === void 0 ? void 0 : _b.length) > 0 ||
                props.message.thread !== undefined ||
                ((_c = props.message.embeds) === null || _c === void 0 ? void 0 : _c.length) > 0 ||
                ((_d = props.message.components) === null || _d === void 0 ? void 0 : _d.length) > 0 },
            props.message.attachments.map((attachment) => (React.createElement(Attachment, { key: attachment.url, attachment: attachment }))), (_e = props.message.sticker_items) === null || _e === void 0 ? void 0 :
            _e.map((sticker) => (React.createElement(Sticker, { key: sticker.id, sticker: sticker }))),
            embedImages.length > 0 ? (React.createElement(Embed, { key: props.message.embeds[0].url, embed: props.message.embeds[0], images: embedImages })) : (props.message.embeds.map((embed) => (React.createElement(Embed, { key: embed.url, embed: embed, images: undefined })))),
            ((_f = props.message.reactions) === null || _f === void 0 ? void 0 : _f.length) > 0 && (React.createElement(Reactions, { reactions: props.message.reactions })),
            ((_g = props.message.components) === null || _g === void 0 ? void 0 : _g.length) > 0 && (React.createElement(Components, { components: props.message.components, message: props.message })),
            !props.noThreadButton && props.message.thread && (React.createElement(ThreadButton, { hasReply: props.message.referenced_message !== undefined, thread: props.message.thread, messageId: props.message.id, messageContent: props.message.content, messageType: props.message.type }))))));
}
export default memo(Content);
//# sourceMappingURL=index.js.map