import * as React from "react";
import { useMemo } from "react";
import ChatTag from "../ChatTag";
import RoleIcon from "./RoleIcon";
import getAvatar from "../utils/getAvatar";
import * as Styles from "./style/author";
import { useConfig } from "../core/ConfigContext";
import getDisplayName from "../utils/getDisplayName";
function MessageAuthor({ onlyShowUsername, author, avatarAnimated, crossPost, referenceGuild, }) {
    var _a;
    const { resolveRole } = useConfig();
    const isGuildMember = "joined_at" in author;
    const user = isGuildMember ? author.user : author;
    const displayName = isGuildMember
        ? (_a = author.nick) !== null && _a !== void 0 ? _a : getDisplayName(author.user)
        : getDisplayName(author);
    const dominantRoleIconRole = useMemo(() => {
        if (!isGuildMember || !resolveRole)
            return null;
        const [role] = author.roles
            .map((id) => resolveRole(id))
            .filter((role) => role !== null && (role.icon !== null || role.unicode_emoji !== null))
            .sort((a, b) => b.position - a.position);
        if (!role)
            return null;
        return role;
    }, [isGuildMember, resolveRole, author]);
    const dominantRoleColor = useMemo(() => {
        if (!isGuildMember || !resolveRole)
            return null;
        const [role] = author.roles
            .map((id) => resolveRole(id))
            .filter((r) => r !== undefined && r.color !== 0)
            .sort((a, b) => b.position - a.position);
        const color = role === null || role === void 0 ? void 0 : role.color;
        if (!color)
            return null;
        return color > 0 ? `#${color.toString(16).padStart(6, "0")}` : undefined;
    }, [isGuildMember, resolveRole, author]);
    if (onlyShowUsername) {
        return (React.createElement(Styles.MessageAuthor, null,
            React.createElement(Styles.Username, { style: { color: dominantRoleColor } }, displayName)));
    }
    return (React.createElement(Styles.MessageAuthor, null,
        React.createElement(Styles.Avatar, { src: getAvatar(user, {
                animated: avatarAnimated !== null && avatarAnimated !== void 0 ? avatarAnimated : false,
            }), draggable: false }),
        React.createElement(Styles.Username, { style: { color: dominantRoleColor } }, displayName),
        dominantRoleIconRole !== null && (React.createElement(RoleIcon, { role: dominantRoleIconRole })),
        React.createElement(ChatTag, { author: user, crosspost: crossPost, referenceGuild: referenceGuild })));
}
export default MessageAuthor;
//# sourceMappingURL=MessageAuthor.js.map