import React, { memo, useMemo } from "react";
import MessageAuthor from "../MessageAuthor";
import Content from "../../Content";
import Moment from "moment";
import Tooltip from "../../Tooltip";
import getAvatar from "../../utils/getAvatar";
import LargeTimestamp from "../LargeTimestamp";
import ChatTag from "../../ChatTag";
import * as Styles from "../style/message";
import { MessageType, } from "discord-api-types/v10";
import { useConfig } from "../../core/ConfigContext";
import getDisplayName from "../../utils/getDisplayName";
function getMiniAvatarUrl(referencedMessage, interaction) {
    const getAvatarSettings = {
        size: 16,
        animated: false,
    };
    if (interaction !== undefined)
        return getAvatar(interaction.user, getAvatarSettings);
    if (referencedMessage !== undefined && referencedMessage !== null)
        return getAvatar(referencedMessage.author, getAvatarSettings);
    return null;
}
const ReplyInfo = memo((props) => {
    var _a;
    const miniAvatarUrl = useMemo(() => getMiniAvatarUrl(props.referencedMessage, props.interaction), [props.referencedMessage, props.interaction]);
    const { resolveRole, resolveChannel, resolveMember } = useConfig();
    const miniUserName = useMemo(() => {
        var _a;
        if (!props.interaction && !props.referencedMessage)
            return null;
        const user = props.interaction !== undefined
            ? props.interaction.user
            : props.referencedMessage.author;
        if (!resolveChannel)
            return getDisplayName(user);
        const channel = resolveChannel(props.channelId);
        if (!channel || !("guild_id" in channel))
            return getDisplayName(user);
        const guildMember = resolveMember(props.referencedMessage.author.id, channel.guild_id);
        if (!guildMember)
            return getDisplayName(user);
        return (_a = guildMember.nick) !== null && _a !== void 0 ? _a : getDisplayName(guildMember.user);
    }, [props.referencedMessage, props.interaction, resolveChannel]);
    const miniUserNameColorHex = useMemo(() => {
        if (!props.referencedMessage)
            return null;
        const channel = resolveChannel(props.referencedMessage.channel_id);
        if (!channel || !("guild_id" in channel))
            return null;
        const guildMember = resolveMember(props.referencedMessage.author.id, channel.guild_id);
        if (!guildMember)
            return null;
        const [role] = guildMember.roles
            .map((id) => resolveRole(id))
            .filter((r) => r !== undefined && r.color !== 0)
            .sort((a, b) => b.position - a.position);
        const color = role === null || role === void 0 ? void 0 : role.color;
        if (!color)
            return null;
        return color > 0 ? `#${color.toString(16).padStart(6, "0")}` : undefined;
    }, [resolveRole]);
    const unknownReply = !props.referencedMessage && !props.interaction;
    return (React.createElement(Styles.ReplyInfo, null,
        React.createElement(Styles.ReplySpine, null),
        unknownReply ? (React.createElement(React.Fragment, null,
            React.createElement(Styles.UnknownReplyIcon, { width: 12, height: 12, svg: "IconUnknownReply" }),
            React.createElement(Styles.UnknownReply, null, "Original message was deleted or is unknown."))) : (React.createElement(Styles.ReplyUser, null,
            React.createElement(Styles.MiniUserAvatar, { src: miniAvatarUrl }),
            props.referencedMessage && (React.createElement(ChatTag, { author: props.referencedMessage.author, crosspost: !!(props.referencedMessage.flags & (1 << 1)), referenceGuild: (_a = props.referencedMessage.message_reference) === null || _a === void 0 ? void 0 : _a.guild_id })),
            React.createElement(Styles.MiniUserName, { style: { color: miniUserNameColorHex } },
                props.mentioned && "@",
                miniUserName))),
        props.referencedMessage ? (React.createElement(Content, { message: props.referencedMessage, isReplyContent: true })) : (props.interaction && (React.createElement(Styles.SlashCommand, null,
            "used",
            " ",
            React.createElement(Styles.SlashCommandText, null,
                !props.isContextMenuInteraction ? "/" : "",
                props.interaction.name))))));
});
function NormalMessage(props) {
    var _a, _b, _c;
    const shouldShowReply = props.message.type === MessageType.Reply ||
        Boolean(props.message.interaction);
    const { resolveChannel, resolveMember, currentUser } = useConfig();
    const member = useMemo(() => {
        const channel = resolveChannel(props.message.channel_id);
        if (!channel || !("guild_id" in channel))
            return null;
        return resolveMember(props.message.author.id, channel.guild_id);
    }, [resolveChannel, resolveMember]);
    const isUserMentioned = useMemo(() => {
        var _a, _b;
        const userMentionedOverride = (_b = (_a = props.overrides) === null || _a === void 0 ? void 0 : _a.userMentioned) !== null && _b !== void 0 ? _b : false;
        if (userMentionedOverride)
            return true;
        const user = currentUser();
        if (!user)
            return false;
        return (props.message.mentions.find(({ id }) => id === user.id) !== undefined);
    }, [currentUser, props.message.mentions, (_a = props.overrides) === null || _a === void 0 ? void 0 : _a.userMentioned]);
    if (props.isFirstMessage)
        return (React.createElement(Styles.Message, { mentioned: isUserMentioned },
            shouldShowReply && (React.createElement(ReplyInfo, { channelId: props.message.channel_id, referencedMessage: props.message.referenced_message, mentioned: props.message.mentions.some((m) => { var _a; return m.id === ((_a = props.message.referenced_message) === null || _a === void 0 ? void 0 : _a.author.id); }), interaction: props.message.interaction, isContextMenuInteraction: props.isContextMenuInteraction })),
            React.createElement(Styles.MessageHeaderBase, null,
                React.createElement(MessageAuthor, { author: member !== null && member !== void 0 ? member : props.message.author, avatarAnimated: (_b = props.isHovered) !== null && _b !== void 0 ? _b : false, crossPost: Boolean(props.message.flags & (1 << 1)), referenceGuild: (_c = props.message.message_reference) === null || _c === void 0 ? void 0 : _c.guild_id }),
                props.hideTimestamp || (React.createElement(LargeTimestamp, { timestamp: props.message.timestamp }))),
            React.createElement(Content, { message: props.message, noThreadButton: props.noThreadButton })));
    return (React.createElement(Styles.Message, { mentioned: isUserMentioned },
        React.createElement(Tooltip, { placement: "top", overlay: Moment(props.message.timestamp).format("LLLL"), mouseEnterDelay: 1 },
            React.createElement(Styles.SmallTimestamp, { dateTime: props.message.timestamp }, Moment(props.message.timestamp).format("h:mm A"))),
        React.createElement(Content, { message: props.message, noThreadButton: props.noThreadButton })));
}
export default NormalMessage;
//# sourceMappingURL=NormalMessage.js.map