import Moment from "moment";
import Tooltip from "../../../Tooltip";
import React from "react";
import { commonComponentId, css, styled, theme, } from "../../../Stitches/stitches.config";
var TimestampStyle;
(function (TimestampStyle) {
    TimestampStyle["ShortTime"] = "t";
    TimestampStyle["LongTime"] = "T";
    TimestampStyle["ShortDate"] = "d";
    TimestampStyle["LongDate"] = "D";
    TimestampStyle["ShortDateTime"] = "f";
    TimestampStyle["LongDateTime"] = "F";
    TimestampStyle["RelativeTime"] = "R";
})(TimestampStyle || (TimestampStyle = {}));
export function Timestamp({ data: { timestamp, style } }) {
    const time = Moment(parseInt(timestamp) * 1000);
    // https://momentjs.com/docs/#/displaying/format/
    const formats = {
        t: "LT",
        T: "LTS",
        d: "L",
        D: "LL",
        f: "LLL",
        F: "LLLL",
    };
    function displayTime(style) {
        return time.format(formats[style]);
    }
    return (React.createElement(Tooltip, { mouseEnterDelay: 0.1, placement: "top", overlay: displayTime(TimestampStyle.LongDateTime) },
        React.createElement(TSSpan, null, style === TimestampStyle.RelativeTime
            ? time.fromNow()
            : displayTime(style !== null && style !== void 0 ? style : TimestampStyle.ShortDateTime))));
}
const TSSpan = styled.withConfig({
    displayName: "timestamp-span",
    componentId: commonComponentId,
})("span", css({
    backgroundColor: theme.colors.primaryOpacity10,
    borderRadius: 3,
    padding: `0 ${theme.space.xs}`,
}));
//# sourceMappingURL=Timestamp.js.map