import * as Styles from "./style";
import * as React from "react";
import { ChannelType } from "discord-api-types/v10";
import { useConfig } from "../../../../core/ConfigContext";
import SimpleMarkdown from "simple-markdown";
import SvgFromUrl from "../../../../SvgFromUrl";
function getChannelTypeSvg(type) {
    switch (type) {
        case ChannelType.GuildVoice:
            return "IconVoiceChannel";
        case ChannelType.GuildStageVoice:
            return "IconStageChannel";
        default:
            return "IconTextChannel";
    }
}
function ChannelMention({ channelId }) {
    const { resolveChannel, channelMentionOnClick } = useConfig();
    const channel = resolveChannel(channelId);
    if (!channel) {
        return (React.createElement(Styles.Mention, null,
            React.createElement(Styles.MentionIcon, { as: SvgFromUrl, width: 16, height: 16, svg: "IconTextChannel" }),
            "Unknown"));
    }
    const icon = getChannelTypeSvg(channel.type);
    return (React.createElement(Styles.Mention, { onClick: () => channelMentionOnClick === null || channelMentionOnClick === void 0 ? void 0 : channelMentionOnClick(channel), canBeClicked: channelMentionOnClick !== undefined },
        React.createElement(Styles.MentionIcon, { as: SvgFromUrl, width: 16, height: 16, svg: icon }),
        channel.name));
}
export const channelMention = {
    order: SimpleMarkdown.defaultRules.text.order,
    match: (source) => /^<#([0-9]+?)>/.exec(source),
    parse: ([, id]) => ({ id }),
    react: ({ id }, recurseParse, state) => (React.createElement(ChannelMention, { channelId: id, key: state.key })),
};
//# sourceMappingURL=channelMention.js.map