import memoize from "memoizee";
import * as R from "ramda";
import baseRules from "./ast";
import { Highlighter } from "./elements";
import * as Styles from "./elements";
import { astToString, flattenAst, recurse } from "./util";
import SimpleMarkdown, { defaultRules } from "simple-markdown";
import TextSpoiler from "./elements/TextSpoiler";
import { Timestamp } from "./elements/Timestamp";
import React from "react";
import { InlineCode } from "./elements/code/style";
import { findDefaultEmojiByUnicode } from "../../emojiData";
function parserFor(rules, returnAst) {
    const parser = SimpleMarkdown.parserFor(rules);
    const renderer = SimpleMarkdown.outputFor(rules, "react");
    return memoize((input = "", inline = true, state = {}, transform = null) => {
        if (!inline) {
            input += "\n\n";
        }
        const parse = R.pipe.apply(this, [parser, flattenAst, transform, !returnAst && renderer].filter(Boolean));
        return parse(input, Object.assign({ inline }, state));
    }, {
        normalizer: (...args) => JSON.stringify(args),
    });
}
function createRules(rule) {
    const { paragraph, url, link, codeBlock, inlineCode, blockQuote, spoiler, timestamp, command, } = rule;
    return Object.assign(Object.assign({}, rule), { heading: Object.assign(Object.assign({}, defaultRules.heading), { match: (source, state) => {
                const prevCaptureStr = state.prevCapture === null ? "" : state.prevCapture[0];
                const isStartOfLineCapture = /(?:^|\n)( *)$/.exec(prevCaptureStr);
                if (isStartOfLineCapture) {
                    source = isStartOfLineCapture[1] + source;
                    return /^ *(#{1,3})([^\n]+?)(?:\n|$)/.exec(source);
                }
                return null;
            }, react(node, parse, state) {
                return (React.createElement(Styles.Heading, { key: state.key, kind: node.level }, parse(node.content, state)));
            } }), s: {
            order: rule.u.order,
            match: SimpleMarkdown.inlineRegex(/^~~([\s\S]+?)~~(?!_)/),
            parse: rule.u.parse,
            react: (node, recurseOutput, state) => (React.createElement("s", { key: state.key }, recurseOutput(node.content, state))),
        }, paragraph: Object.assign(Object.assign({}, paragraph), { react: (node, recurseOutput, state) => (React.createElement("p", { key: state.key }, recurseOutput(node.content, state))) }), url: Object.assign(Object.assign({}, url), { match: SimpleMarkdown.inlineRegex(/^((https?|steam):\/\/[^\s<]+[^<.,:;"')\]\s])/) }), link: Object.assign(Object.assign({}, link), { react: (node, recurseOutput, state) => (React.createElement(Styles.Link, { title: node.title || astToString(node.content), href: SimpleMarkdown.sanitizeUrl(node.target), target: "_blank", rel: "noreferrer", key: state.key }, recurseOutput(node.content, state))) }), inlineCode: Object.assign(Object.assign({}, inlineCode), { react: (node, recurseOutput, state) => (React.createElement(InlineCode, { key: state.key }, recurse(node, recurseOutput, state))) }), codeBlock: Object.assign(Object.assign({}, codeBlock), { react: (node, recurseOutput, state) => (React.createElement(Highlighter, { key: state.key, language: node.lang }, recurse(node, recurseOutput, state))) }), blockQuote: Object.assign(Object.assign({}, blockQuote), { react: (node, recurseOutput, state) => (React.createElement(Styles.QuoteContainer, { key: state.key },
                React.createElement(Styles.QuoteBar, null),
                React.createElement(Styles.Quote, null, recurse(node, recurseOutput, state)))) }), spoiler: Object.assign(Object.assign({}, spoiler), { react: (node, recurseOutput, state) => (React.createElement(TextSpoiler, { content: recurse(node, recurseOutput, state), key: state.key })) }), timestamp: Object.assign(Object.assign({}, timestamp), { react: (data, recurseOutput, state) => (React.createElement(Timestamp, { data: data, key: state.key })) }), command: Object.assign(Object.assign({}, command), { react: ({ name }) => "/" + name }) });
}
const rulesWithoutMaskedLinks = createRules(Object.assign(Object.assign({}, baseRules), { link: Object.assign(Object.assign({}, baseRules.link), { match: () => null }) }));
const parse = parserFor(rulesWithoutMaskedLinks);
export const parseAllowLinks = parserFor(createRules(baseRules));
export const parseEmbedTitle = parserFor(R.omit(["codeBlock", "br", "mention", "channelMention", "roleMention"], rulesWithoutMaskedLinks));
function handleUnicodeEmojis(content) {
    return content.replace(/(\p{RI}\p{RI}|\p{Emoji}(?:\p{EMod}|\u{FE0F}\u{20E3}?|[\u{E0020}-\u{E007E}]+\u{E007F})?(?:\u{200D}(?:\p{RI}\p{RI}|\p{Emoji}(\p{EMod}|\u{FE0F}\u{20E3}?|[\u{E0020}-\u{E007E}]+\u{E007F})?))*)/gu, (match) => {
        const emojiResult = findDefaultEmojiByUnicode(match);
        if (!emojiResult)
            return match;
        return `:${emojiResult.emoji}:`;
    });
}
function Markdown({ children: content, mentions, users, }) {
    const unicodeEmojisHandled = handleUnicodeEmojis(content);
    return content
        ? parse(unicodeEmojisHandled, undefined, { mentions, users })
        : null;
}
export function LinkMarkdown({ children: content, mentions, users, }) {
    const unicodeEmojisHandled = handleUnicodeEmojis(content);
    return content
        ? parseAllowLinks(unicodeEmojisHandled, undefined, { mentions, users })
        : null;
}
export default Markdown;
//# sourceMappingURL=index.js.map